AdaptiveBottomSheet<T> class

Constructors

AdaptiveBottomSheet({required BuildContext context, Widget? child, String? title, String? supTitle, TextStyle? titleTxtStyle, double borderRadius = 30, double? titleBottomPadding, EdgeInsetsGeometry? contentPadding, double? sheetHeightFraction, Color? bgColor, bool hasPillGesture = true, bool? isScrollControlled, bool? isReverseScrolling, VoidCallback? onWillPop, VoidCallback? onOpened, void onClosed(T? result)?})

Properties

bgColor Color?
final
borderRadius double
final
child Widget?
final
contentPadding EdgeInsetsGeometry?
final
context BuildContext
final
hashCode int
The hash code for this object.
no setterinherited
hasPillGesture bool
final
isReverseScrolling bool?
final
isScrollControlled bool?
final
onClosed → void Function(T? result)?
final
onOpened VoidCallback?
final
onWillPop VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sheetHeightFraction double?
final
supTitle String?
final
title String?
final
titleBottomPadding double?
final
titleTxtStyle TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show() Future<T?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited